summaryrefslogtreecommitdiffstats
path: root/src/com/android/contacts/common/list/ProfileAndContactsLoader.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/contacts/common/list/ProfileAndContactsLoader.java')
-rw-r--r--src/com/android/contacts/common/list/ProfileAndContactsLoader.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/com/android/contacts/common/list/ProfileAndContactsLoader.java b/src/com/android/contacts/common/list/ProfileAndContactsLoader.java
index c19737d9..698ef96f 100644
--- a/src/com/android/contacts/common/list/ProfileAndContactsLoader.java
+++ b/src/com/android/contacts/common/list/ProfileAndContactsLoader.java
@@ -61,8 +61,8 @@ public class ProfileAndContactsLoader extends CursorLoader {
Cursor cursor = null;
try {
cursor = super.loadInBackground();
- } catch (NullPointerException e) {
- // Ignore NPEs thrown by providers
+ } catch (NullPointerException | SecurityException e) {
+ // Ignore NPEs and SecurityExceptions thrown by providers
}
final Cursor contactsCursor = cursor;
cursors.add(contactsCursor);